@@ -59,29 +59,32 @@ class Saori(SAORI):
         elif req_type == 'GET Version':
             return self.RESPONSE[204]
         elif req_type == 'EXECUTE':
-            if argument[0] not in self.function:
-                return self.RESPONSE[400]
-            name = argument[0]
-            argument = argument[1:]
-            if self.function[name][1] == [None]:
-                pass
-            elif len(argument) not in self.function[name][1]:
-                return self.RESPONSE[400]
-            self.value = []
-            result = self.function[name][0](argument)
-            if result is not None and result != '':
-                s = 'SAORI/1.0 200 OK\r\nResult: {0}\r\n'.format(result)
-                if self.value:
-                    for i in range(len(self.value)):
-                        s = ''.join((s, 'Value{0:d}: {1}\r\n'.format(i, self.value[i])))
-                s = ''.join((s, 'Charset: {0}\r\n'.format(charset)))
-                s = ''.join((s, '\r\n'))
-                return s.encode(charset)
-            else:
-                return self.RESPONSE[204]
+            result = self.execute(argument)
         else:
             return self.RESPONSE[400]
 
+    def execute(self, args):
+        if args[0] not in self.function:
+            return self.RESPONSE[400]
+        name = args[0]
+        args = args[1:]
+        if self.function[name][1] == [None]:
+            pass
+        elif len(args) not in self.function[name][1]:
+            return self.RESPONSE[400]
+        self.value = []
+        result = self.function[name][0](args)
+        if result is not None and result != '':
+            s = 'SAORI/1.0 200 OK\r\nResult: {0}\r\n'.format(result)
+            if self.value:
+                for i in range(len(self.value)):
+                    s = ''.join((s, 'Value{0:d}: {1}\r\n'.format(i, self.value[i])))
+            s = ''.join((s, 'Charset: {0}\r\n'.format(charset)))
+            s = ''.join((s, '\r\n'))
+            return s.encode(charset)
+        else:
+            return self.RESPONSE[204]
+
     def ssu_is_empty(self, args):
         return 1 if not args else 0
 
