@@ -1267,7 +1267,7 @@ class Console:
     def open_file_chooser(self):
         response = self.file_chooser.run()
         if response == Gtk.ResponseType.OK:
-            filename = self.file_chooser.get_filename()
+            filename = self.file_chooser.get_filename() # XXX: don't use os.fsencode() here
             self.app.do_install(filename)
             self.update()
         elif response == Gtk.ResponseType.CANCEL:
@@ -1315,13 +1315,13 @@ class Console:
                 urllib.parse.urlparse(uri)
             pathname = urllib.request.url2pathname(path)
             if scheme == 'file' and os.path.exists(pathname):
-                filelist.append(pathname)
+                filelist.append(pathname) # XXX: don't use os.fsencode() here
+            elif scheme == 'http' or scheme == 'ftp':
+                filelist.append(uri)
         if filelist:
-            filelist = [os.fsencode(filename) for filename in filelist]
             for filename in filelist:
                 self.app.do_install(filename)
             self.update()
-        return True
 
 
 class UsageDialog:
